==> github-com-ant-design-ant-design-3.13.5.jar: META-INF/resources/webjars/github-com-ant-design-ant-design/3.13.5/spec/download.en-US.md <==
---
category: Other
order: 0
title: Resources
---

Please find below some of the design resources and tools about Ant Design that we consider valuable. More of this is still being collected.

<div class="resource-cards">
  <a target="_blank" href="https://github.com/ant-design/ant-design/releases/download/resource/Ant.Design.Components.3.12.0.sketch" class="resource-card">
    <div class="resource-card-icon">
      <img width="65" src="https://gw.alipayobjects.com/zos/rmsportal/pKfDZnzocrbAOSzDQOQq.png">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">
        RENEW Sketch Symbols
        <span class="resource-card-hot-badge">NEW</span>
      </span>
      <span class="resource-card-description">Sketch Symbols for Desktop</span>
    </div>
  </a>
  <a target="_blank" href="https://landing.ant.design/docs/download" class="resource-card">
    <div class="resource-card-icon">
      <img width="65" src="https://gw.alipayobjects.com/zos/rmsportal/EAHlyTmYeDtTkZIPbUnP.svg">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">
        Ant Design Landing
        <span class="resource-card-hot-badge">NEW</span>
      </span>
      <span class="resource-card-description">Landing Templates</span>
    </div>
  </a>
  <a target="_blank" href="https://github.com/ant-design/ant-design/releases/download/resource/Ant.Design.Mobile.Template.sketch" class="resource-card">
    <div class="resource-card-icon">
      <img width="41" src="https://gw.alipayobjects.com/zos/rmsportal/rFMdPVzabtQwxONUuVFr.png">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">Mobile Components</span>
      <span class="resource-card-description">Sketch Symbols File for Mobile</span>
    </div>
  </a>
  <a target="_blank" href="https://github.com/ant-design/ant-design/releases/download/resource/Ant.Design.Pro.sketch" class="resource-card">
    <div class="resource-card-icon">
      <img width="65" src="https://gw.alipayobjects.com/zos/rmsportal/ibCZMxKsTUzDbwTEdcTC.svg">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">Ant Design Pro</span>
      <span class="resource-card-description">Common Templates and Pages</span>
    </div>
  </a>
  <a target="_blank" href="http://library.ant.design" class="resource-card">
    <div class="resource-card-icon">
      <img width="50" src="https://gw.alipayobjects.com/zos/rmsportal/TXrKQUJBTuwSTGimGYYn.png">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">Ant Design Library</span>
      <span class="resource-card-description">A powerful Axure library of Ant Design</span>
    </div>
  </a>
  <a target="_blank" href="http://kitchen.alipay.com" class="resource-card">
    <div class="resource-card-icon">
      <img width="65" src="https://gw.alipayobjects.com/zos/rmsportal/ATYZYtJhchhONKObIwXT.png">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">
        Kitchen
        <span class="resource-card-hot-badge">HOT</span>
      </span>
      <span class="resource-card-description">A Sketch plugin with a collection of great tools</span>
    </div>
  </a>
  <a target="_blank" href="http://ux.ant.design" class="resource-card">
    <div class="resource-card-icon">
      <img width="64" src="https://gw.alipayobjects.com/zos/rmsportal/yMULSUQQyhoEGrCXlovN.png">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">Ant UX</span>
      <span class="resource-card-description">A series prototypes that help creating application structure and user flow</span>
    </div>
  </a>
  <a target="_blank" href="https://www.xiaopiu.com/topic/ant-design" class="resource-card">
    <div class="resource-card-icon">
      <img width="72" src="https://img.xiaopiu.com/userImages/img753167822272f8.png">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">Ant Design Prototype (xiaopiu)</span>
      <span class="resource-card-description">Online Ant Design library and interactive prototype</span>
    </div>
  </a>
</div>

==> github-com-ant-design-ant-design-3.21.4.jar: META-INF/resources/webjars/github-com-ant-design-ant-design/3.21.4/spec/download.en-US.md <==
---
category: Other
order: 0
title: Resources
---

Please find below some of the design resources and tools about Ant Design that we consider valuable. More of this is still being collected.

<div class="resource-cards">
  <a target="_blank" href="https://github.com/ant-design/ant-design/releases/download/resource/Ant.Design.Components.3.12.0.sketch" class="resource-card">
    <div class="resource-card-icon">
      <img width="65" src="https://gw.alipayobjects.com/zos/rmsportal/pKfDZnzocrbAOSzDQOQq.png">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">
        RENEW Sketch Symbols
      </span>
      <span class="resource-card-description">Sketch Symbols for Desktop</span>
    </div>
  </a>
  <a target="_blank" href="https://github.com/ant-design/ant-design/releases/download/resource/Ant.Design.Mobile.Template.sketch" class="resource-card">
    <div class="resource-card-icon">
      <img width="41" src="https://gw.alipayobjects.com/zos/rmsportal/rFMdPVzabtQwxONUuVFr.png">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">Mobile Components</span>
      <span class="resource-card-description">Sketch Symbols File for Mobile</span>
    </div>
  </a>
  <a target="_blank" href="https://github.com/ant-design/ant-design/releases/download/resource/Ant.Design.Pro.sketch" class="resource-card">
    <div class="resource-card-icon">
      <img width="65" src="https://gw.alipayobjects.com/zos/rmsportal/ibCZMxKsTUzDbwTEdcTC.svg">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">Ant Design Pro</span>
      <span class="resource-card-description">Common Templates and Pages</span>
    </div>
  </a>
  <a target="_blank" href="http://library.ant.design" class="resource-card">
    <div class="resource-card-icon">
      <img width="50" src="https://gw.alipayobjects.com/zos/rmsportal/TXrKQUJBTuwSTGimGYYn.png">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">Ant Design Library</span>
      <span class="resource-card-description">A powerful Axure library of Ant Design</span>
    </div>
  </a>
  <a target="_blank" href="http://kitchen.alipay.com" class="resource-card">
    <div class="resource-card-icon">
      <img width="65" src="https://gw.alipayobjects.com/zos/rmsportal/ATYZYtJhchhONKObIwXT.png">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">
        Kitchen
        <span class="resource-card-hot-badge">HOT</span>
      </span>
      <span class="resource-card-description">A Sketch plugin with a collection of great tools</span>
    </div>
  </a>
  <a target="_blank" href="https://landing.ant.design/docs/download" class="resource-card">
    <div class="resource-card-icon">
      <img width="65" src="https://gw.alipayobjects.com/zos/rmsportal/EAHlyTmYeDtTkZIPbUnP.svg">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">
        Ant Design Landing
      </span>
      <span class="resource-card-description">Landing Templates</span>
    </div>
  </a>
  <a target="_blank" href="http://ux.ant.design" class="resource-card">
    <div class="resource-card-icon">
      <img width="64" src="https://gw.alipayobjects.com/zos/rmsportal/yMULSUQQyhoEGrCXlovN.png">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">Ant UX</span>
      <span class="resource-card-description">A series prototypes that help creating application structure and user flow</span>
    </div>
  </a>
  <a target="_blank" href="https://www.xiaopiu.com/topic/ant-design" class="resource-card">
    <div class="resource-card-icon">
      <img width="72" src="https://img.xiaopiu.com/userImages/img753167822272f8.png">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">Ant Design Prototype (xiaopiu)</span>
      <span class="resource-card-description">Online Ant Design library and interactive prototype</span>
    </div>
  </a>
  <a target="_blank" href="https://www.antforfigma.com" class="resource-card">
    <div class="resource-card-icon">
      <img width="65" src="https://antforfigma.com/images/antforfigma-icon.png">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">
        UI Kit for Figma
        <span class="resource-card-hot-badge">NEW</span>
      </span>
      <span class="resource-card-description">Large library of components and styles for Desktop</span>
    </div>
  </a>
  <a target="_blank" href="https://store.framer.com/package/bhaveshchow/ant-design-system" class="resource-card">
    <div class="resource-card-icon">
      <img width="65" src="https://raw.githubusercontent.com/bhaveshc20/antdesign-framer/master/framerant-icon.png">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">
        UI Kit for Framer X
        <span class="resource-card-hot-badge">NEW</span>
      </span>
      <span class="resource-card-description">Library of fully customizable components</span>
    </div>
  </a>
</div>
